@@ -56,10 +56,10 @@ tcplLoadChem <- function(field = NULL, val = NULL, exact = TRUE,
                          include.spid = TRUE) {
   tbl <- c("chemical", "sample")
   ## Variable-binding to pass R CMD Check
-  code <- casn <- chid <- chnm <- NULL
+  code <- casn <- chid <- chnm <- dsstox_substance_id <- NULL
   
   if (!is.null(field)) {
-    vfield <- c("chid", "spid", "chnm", "casn", "code", "chem.only")
+    vfield <- c("chid", "spid", "chnm", "casn", "code", "chem.only","dsstox_substance_id")
     if (!field %in% vfield) stop("Invalid 'field' value.")
   }
   
@@ -81,7 +81,7 @@ tcplLoadChem <- function(field = NULL, val = NULL, exact = TRUE,
   
   if (include.spid) return (dat)
   
-  dat <- unique(dat[ , list(chid, chnm, casn, code)])
+  dat <- unique(dat[ , list(chid, chnm, casn, code, dsstox_substance_id)])
 
   dat[]
   
